
/*
 * STAGE: point to a CSV file ;
 */
FILENAME REFFILE '/folders/myfolders/Week1/Data/AMZN.csv';

PROC IMPORT DATAFILE=REFFILE
	DBMS=CSV
	OUT=WORK.AMZN;
	GETNAMES=YES;
RUN;

* what's in the dataset ;
PROC PRINT DATA=WORK.AMZN(obs=10); 
RUN;

/*
 * STRUCTURE: sort that thing by date;
 */

PROC SORT DATA=WORK.amzn;
	BY date;
RUN;

/* 
 * Two ways of creating Moving Averages. 
 * first way is lag
 */

data amzn_mva;
	set work.amzn_1;
	retain adj_close;
	/*
	 * the LAG way of creating Moving Averages
	 */
	mva_5_day = (adj_close + lag(adj_close) + lag2(adj_close) + lag3(adj_close) + lag4(adj_close))/5;
run;
/*
 * Second way is with arrays 
 */
data amzn_mva;
	set work.amzn_1;
	/*
	 * Array way of creating Moving Averages 
	 */
	array mva_(5) _temporary_;
	do i = 5 to 2 by -1;
		mva_(i) = mva_(i-1);
	end;
	mva_(1) = adj_close;
	mva5  = sum(of mva_(*))/5;
	/* alternatively you can reference the array elements... I prefer this... 
	
		mva5  = sum(of mva_[1], mva_[2], mva_[3], mva_[4], mva_[5] )/5;
	
	*/
	
	/* you need some conditional logic to create buy and sell signals */
	if _N_ GT 30 then do;
		if mva5 > adj_close then signal = 'LONG';
		if mva5 < adj_close then signal = 'SELL';
		if signal NE lag(signal) then action = signal;
	end;
	where date > MDY(1,1,2017);
run; 

/*
 * do something about something about orders... 
 * probably a DATA Step with filter and your file should be LONG,SELL,LONG,SELL
 * 
 * finally, there is that profit snip of code... what does it tell you? 
 */
	
/*
 * Analyze: create a plot or two here's an example... 
 */
proc sgplot data=WORK.amzn_mva;
	series x=date y=mva30 /;
	series x=date y=adj_close /;
	xaxis grid;
	yaxis grid;
	* identify buys and sells with differen color ref lines ;
	refline '15FEB2017'D  '01APR2017'D / axis=x LINEATTRS=(color=green);
	refline '27MAR2017'D / axis=x LINEATTRS=(color=red);
	where date > MDY(1,1,2017);
run;

/* 
 * Do something about exporting your orders file to CSV... PROC EXPORT 
 */


/*
 * this datastep reads in AMZN, calucates the first day closing price(first_day), 
 * daily returns(daily_ret), cumulative growth (daily_grw)
 * if you bought 1 share of AMZN what is your total return?  
 * 
 */
DATA AMZN_1;
	LENGTH daily_ret daily_grw first_day 8.;
	FORMAT date Date9.;
	SET work.amzn;

	IF _N_ EQ 1 THEN DO;
		first_day = adj_close;
	END;
	RETAIN adj_close first_day;
	
	
	daily_ret = adj_close / lag(adj_close) - 1;
	daily_grw = adj_close / first_day;
	
RUN; 
 
ods graphics / reset width=6.4in height=4.8in imagemap;

* probably unecessary because it's from previous step but good practice; 
PROC SORT DATA=WORK.AMZN_1;
	BY date;
RUN;
